package com.qmth.themis.business.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.qmth.themis.business.bean.backend.InvigilateListBean;
import com.qmth.themis.business.entity.TOeExamRecord;
import com.qmth.themis.business.enums.ExamTypeEnum;
import com.qmth.themis.business.enums.LivenessTypeEnum;
import com.qmth.themis.business.enums.VerifyExceptionEnum;

import java.util.Map;

/**
 * @Description: 考试记录 服务类
 * @Param:
 * @return:
 * @Author: wangliang
 * @Date: 2020/6/25
 */
public interface TOeExamRecordService extends IService<TOeExamRecord> {

    /**
     * 获取考试未完列表
     *
     * @param studentId
     * @param examId
     * @param orgId
     * @return
     */
    public Map getUnFinishExam(Long studentId, Long examId, Long orgId);

    Long saveByPrepare(Long examId, Long examActivityId, Long examStudentId, Long paperId, Integer serialNumber);

    /**
     * 计算客观分
     *
     * @param param
     */
    void calculateObjectiveScore(Map<String, Object> param);

    /**
     * 考试记录数据持久化
     *
     * @param recordId
     */
    public void saveDataByCache(Long recordId);

    void saveFaceVerify(ExamTypeEnum type, Long recordId, Long entryAuthenticationId,
                        VerifyExceptionEnum entryAuthenticationResult);

    void saveLivenessVerify(LivenessTypeEnum type, Long recordId, Long entryAuthenticationId,
                            VerifyExceptionEnum entryAuthenticationResult);

    /**
     * 考试记录字段同步消息发送
     *
     * @param recordId
     * @param colName
     * @param colValue
     */
    void dataUpdateMq(Long recordId, String colName, Object colValue);

    /**
     * 考试记录字段同步
     *
     * @param recordId
     * @param colName
     * @param colValue
     */
    void dataUpdate(Long recordId, String colName, Object colValue, Integer isDate);

    /**
     * 考试记录初始化消息发送
     *
     * @param param
     */
    void dataInitMq(Map<String, Object> param);

    /**
     * 考试记录初始化
     *
     * @param param
     */
    void dataInit(Map<String, Object> param);

    /**
     * 考试记录字段同步消息发送
     *
     * @param recordId
     * @param colName
     * @param colValue
     * @param isDate
     */
    void dataUpdateMq(Long recordId, String colName, Object colValue, Integer isDate);

    /**
     * 查询实时监控台列表
     *
     * @param iPage
     * @param examId
     * @param examActivityId
     * @param roomCode
     * @param paperDownload
     * @param status
     * @param name
     * @param identity
     * @param minWarningCount
     * @param maxWarningCount
     * @param clientWebsocketStatus
     * @param monitorStatusSource
     * @return
     */
    public IPage<InvigilateListBean> invigilatePageList(IPage<Map> iPage, Long examId,
                                                        Long examActivityId,
                                                        String roomCode,
                                                        Integer paperDownload,
                                                        String status,
                                                        String name,
                                                        String identity,
                                                        Integer minWarningCount,
                                                        Integer maxWarningCount,
                                                        String clientWebsocketStatus,
                                                        String monitorStatusSource);
}
